@@ -1,4 +1,4 @@
-from dkist_fits_validator import spec122_validator
+from dkist_header_validator import spec122_validator
 
 from dkist_data_simulator.spec122 import Spec122Dataset
 
